@@ -290,7 +290,10 @@ static GtkWidget *cache_hint(appdata_t *appdata, cache_t *cache) {
   free(hint);
 
   GtkWidget *button = gtk_button_new_with_label(_("Encrypt/Decrypt"));
-  
+#if defined(USE_MAEMO) && (MAEMO_VERSION_MAJOR == 5)
+  hildon_gtk_widget_set_theme_size(button, 
+	   (HILDON_SIZE_FINGER_HEIGHT | HILDON_SIZE_AUTO_WIDTH));
+#endif  
   gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 0);
   gtk_signal_connect(GTK_OBJECT(button), "clicked",
 	   GTK_SIGNAL_FUNC(on_decrypt), gtk_bin_get_child(GTK_BIN(view)));
@@ -470,7 +473,16 @@ static GtkWidget *cache_tbs(appdata_t *appdata, tb_t *tb) {
 #endif
 }
 
-static GtkWidget *cache_logs(appdata_t *appdata, log_t *log, int is_html) {
+#ifdef ENABLE_BROWSER_INTERFACE
+static void on_gclink_clicked(GtkButton *button, gpointer data) {
+  cache_context_t *context = (cache_context_t*)data;
+  char *url = g_strdup_printf("http://www.geocaching.com/seek/log.aspx?wp=%s", context->cache->id);
+  browser_url(context->appdata, url);
+  g_free(url);
+}
+#endif
+
+static GtkWidget *cache_logs(appdata_t *appdata, cache_context_t *context, log_t *log, int is_html) {
 #ifndef  USE_PANNABLE_AREA
   /* put this inside a scrolled view */
   GtkWidget *scrolled_window = gtk_scrolled_window_new(NULL, NULL);
@@ -480,8 +492,29 @@ static GtkWidget *cache_logs(appdata_t *appdata, log_t *log, int is_html) {
   GtkWidget *pannable_area = hildon_pannable_area_new();
 #endif
 
-  GtkWidget *table = gtk_table_new(4*gpx_number_of_logs(log), 3, FALSE);
+#ifdef ENABLE_BROWSER_INTERFACE
+  gboolean gc_link = strncmp(context->cache->id, "GC", 2) == 0;
+#else
+#define gc_link (FALSE)
+#endif
+
+  GtkWidget *table = gtk_table_new(4*gpx_number_of_logs(log)+(gc_link?1:0), 3, FALSE);
   int cnt = 0;
+
+#ifdef ENABLE_BROWSER_INTERFACE
+  if(gc_link) {
+    GtkWidget *but = gtk_button_new_with_label(_("Post a new log entry for this geocache"));
+#if defined(USE_MAEMO) && (MAEMO_VERSION_MAJOR == 5)
+  hildon_gtk_widget_set_theme_size(but, 
+	   (HILDON_SIZE_FINGER_HEIGHT | HILDON_SIZE_AUTO_WIDTH));
+#endif  
+    gtk_signal_connect(GTK_OBJECT(but), "clicked",
+		       GTK_SIGNAL_FUNC(on_gclink_clicked), context);
+
+    gtk_table_attach_defaults(GTK_TABLE(table), but, 0, 3, 0, 1);
+    cnt++;
+  }
+#endif
   
   /* add all logs to the vbox */
   while(log) {
@@ -631,7 +664,7 @@ GtkWidget *cache_view(appdata_t *appdata, cache_t *cache) {
 
   if(cache->log)
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook), 
-           cache_logs(appdata, cache->log, cache->logs_are_html), 
+     cache_logs(appdata, cache_context, cache->log, cache->logs_are_html), 
 	   gtk_label_new(_("Logs")));
 
   if(cache->wpt)
