@@ -62,6 +62,7 @@
 #if (MAEMO_VERSION_MAJOR < 5)
 #define OSM_GPS_MAP_KEY_FULLSCREEN  HILDON_HARDKEY_FULLSCREEN
 #else
+#define OSD_FONT_SIZE               28
 #define OSM_GPS_MAP_KEY_FULLSCREEN  'f'
 #endif
 #define OSM_GPS_MAP_KEY_ZOOMIN      HILDON_HARDKEY_INCREASE
@@ -97,5 +98,6 @@
 #define OSD_DOUBLE_BUFFER    // render osd/map together offscreen
 #define OSD_GPS_BUTTON       // display a GPS button
 #define OSD_NO_DPAD          // no direction arrows (map is panned)
+#define OSD_SOURCE_SEL       // display source selection tab
 
 #endif // CONFIG_H
