@@ -45,7 +45,6 @@ struct gps_fix_t {
   pos_t pos;          	/* Latitude/Longitude in degrees (valid if mode >= 2) */
     double eph;  	/* Horizontal position uncertainty, meters */
     double altitude;	/* Altitude in meters (valid if mode == 3) */
-    double epv;  	/* Vertical position uncertainty, meters */
     double track;	/* Course made good (relative to true north) */
     double epd;		/* Track uncertainty, degrees */
     double speed;	/* Speed over ground, meters/sec */
@@ -116,9 +115,6 @@ struct gps_data_t {
     int used[MAXCHANNELS];	/* PRNs of satellites used in solution */
     double pdop, hdop, vdop, tdop, gdop;	/* Dilution of precision */
 
-    /* redundant with the estimate elments in the fix structure */
-    double epe;  /* spherical position error, 95% confidence (meters)  */
-
     /* satellite status -- valid when satellites > 0 */
     int satellites;		/* # of satellites in view */
     int PRN[MAXCHANNELS];	/* PRNs of satellite */
@@ -172,7 +168,7 @@ typedef struct gps_state {
   guint idd_changed;
   int fields;
   double latitude, longitude;
-  double heading, epe;
+  double heading, eph;
   gps_sat_t sats;
 #endif
 } gps_state_t;
@@ -181,7 +177,7 @@ void gps_init(appdata_t *appdata);
 void gps_release(appdata_t *appdata);
 pos_t *gps_get_pos(appdata_t *appdata);
 float gps_get_heading(appdata_t *appdata);
-float gps_get_epe(appdata_t *appdata);
+float gps_get_eph(appdata_t *appdata);
 gps_sat_t *gps_get_sats(appdata_t *appdata);
 
 
