@@ -31,7 +31,7 @@ struct icon_data {
   { NULL, 9 },                 /* ICON_HEADING    */
   { NULL, WPT_SYM_MAX+1 },     /* ICON_WPT        */
   { NULL, 1 },                 /* ICON_TB         */
-  { NULL, 13 },                /* ICON_MISC       */
+  { NULL, 9 },                 /* ICON_MISC       */
   { NULL, 3 },                 /* ICON_FILE       */
   { NULL, -1 }
 };
@@ -82,8 +82,7 @@ const char *tb_icon_name[] = {
 /* ICON_MISC         */
 const char *misc_icon_name[] = {
   "maemo-mapper-out", "override", "locked", "unlocked", "found", 
-  "maemo-mapper-in", "note", "delete", "paypal", 
-  "user", "zoomin", "zoomout", "info"
+  "maemo-mapper-in", "note", "delete", "paypal"
 };
 
 /* ICON_FILE         */
