@@ -168,7 +168,8 @@ gpx_t *choose_file(appdata_t *appdata, gboolean whole_dir) {
 
       if(whole_dir)
 	appdata->path = strdup(filename);
-    }
+    } else
+      errorf(_("Load error"));
 
     g_free (filename);
   }
@@ -966,13 +967,16 @@ static GtkWidget *gpxlist_create_view_and_model(appdata_t *appdata,
   GtkTreeIter sel_iter;
   gboolean sel_iter_valid = FALSE;
   while(gpx) {
-    GtkTreeIter         iter;
-    gtk_list_store_append(appdata->gpxstore, &iter);
-    gpxlist_set(appdata->gpxstore, &iter, gpx);
-
-    if(gpx == sel_gpx) {
-      sel_iter = iter;
-      sel_iter_valid = TRUE;
+    /* don't display entries that failed at load */
+    if(!gpx->failed) {
+      GtkTreeIter         iter;
+      gtk_list_store_append(appdata->gpxstore, &iter);
+      gpxlist_set(appdata->gpxstore, &iter, gpx);
+      
+      if(gpx == sel_gpx) {
+	sel_iter = iter;
+	sel_iter_valid = TRUE;
+      }
     }
 
     gpx = gpx->next;
